pub struct AdminHumanDto {
pub human_id: HumanId,
pub status: HumanStatus,
pub github_user_id: GithubUserId,
pub github_login: String,
pub roles: Vec<HumanRole>,
pub created_at: String,
pub disabled_at: Option<String>,
pub deleted_at: Option<String>,
}Expand description
Admin-visible human identity row.
Fields
human_id: HumanIdstatus: HumanStatusgithub_user_id: GithubUserIdgithub_login: Stringroles: Vec<HumanRole>created_at: Stringdisabled_at: Option<String>deleted_at: Option<String>Trait Implementations
Sourceimpl Clone for AdminHumanDto
impl Clone for AdminHumanDto
Sourcefn clone(&self) -> AdminHumanDto
fn clone(&self) -> AdminHumanDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminHumanDto
impl Debug for AdminHumanDto
Sourceimpl<'de> Deserialize<'de> for AdminHumanDto
impl<'de> Deserialize<'de> for AdminHumanDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdminHumanDto
impl JsonSchema for AdminHumanDto
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdminHumanDto
impl RefUnwindSafe for AdminHumanDto
impl Send for AdminHumanDto
impl Sync for AdminHumanDto
impl Unpin for AdminHumanDto
impl UnsafeUnpin for AdminHumanDto
impl UnwindSafe for AdminHumanDto