pub struct AdminHumanListResponse {
pub items: Vec<AdminHumanDto>,
}Expand description
Admin list response for human identities.
Fields
items: Vec<AdminHumanDto>Trait Implementations
Sourceimpl Clone for AdminHumanListResponse
impl Clone for AdminHumanListResponse
Sourcefn clone(&self) -> AdminHumanListResponse
fn clone(&self) -> AdminHumanListResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminHumanListResponse
impl Debug for AdminHumanListResponse
Sourceimpl<'de> Deserialize<'de> for AdminHumanListResponse
impl<'de> Deserialize<'de> for AdminHumanListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdminHumanListResponse
impl JsonSchema for AdminHumanListResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdminHumanListResponse
impl RefUnwindSafe for AdminHumanListResponse
impl Send for AdminHumanListResponse
impl Sync for AdminHumanListResponse
impl Unpin for AdminHumanListResponse
impl UnsafeUnpin for AdminHumanListResponse
impl UnwindSafe for AdminHumanListResponse