pub struct AdminServiceTokenCreatedResponse {
pub token: String,
pub token_record: AdminServiceTokenDto,
}Expand description
Response returned after creating an admin service token.
Fields
token: Stringtoken_record: AdminServiceTokenDtoTrait Implementations
Sourceimpl Clone for AdminServiceTokenCreatedResponse
impl Clone for AdminServiceTokenCreatedResponse
Sourcefn clone(&self) -> AdminServiceTokenCreatedResponse
fn clone(&self) -> AdminServiceTokenCreatedResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for AdminServiceTokenCreatedResponse
impl<'de> Deserialize<'de> for AdminServiceTokenCreatedResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdminServiceTokenCreatedResponse
impl JsonSchema for AdminServiceTokenCreatedResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdminServiceTokenCreatedResponse
impl RefUnwindSafe for AdminServiceTokenCreatedResponse
impl Send for AdminServiceTokenCreatedResponse
impl Sync for AdminServiceTokenCreatedResponse
impl Unpin for AdminServiceTokenCreatedResponse
impl UnsafeUnpin for AdminServiceTokenCreatedResponse
impl UnwindSafe for AdminServiceTokenCreatedResponse