pub struct AdminServiceTokenDto {
pub id: AdminServiceTokenId,
pub label: String,
pub status: String,
pub created_by_human_id: HumanId,
pub created_at: String,
pub last_used_at: Option<String>,
pub expires_at: Option<String>,
pub revoked_by_human_id: Option<HumanId>,
pub revoked_at: Option<String>,
}Expand description
Admin service-token metadata.
Fields
id: AdminServiceTokenIdlabel: Stringstatus: Stringcreated_by_human_id: HumanIdcreated_at: Stringlast_used_at: Option<String>expires_at: Option<String>revoked_by_human_id: Option<HumanId>revoked_at: Option<String>Trait Implementations
Sourceimpl Clone for AdminServiceTokenDto
impl Clone for AdminServiceTokenDto
Sourcefn clone(&self) -> AdminServiceTokenDto
fn clone(&self) -> AdminServiceTokenDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminServiceTokenDto
impl Debug for AdminServiceTokenDto
Sourceimpl<'de> Deserialize<'de> for AdminServiceTokenDto
impl<'de> Deserialize<'de> for AdminServiceTokenDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdminServiceTokenDto
impl JsonSchema for AdminServiceTokenDto
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdminServiceTokenDto
impl RefUnwindSafe for AdminServiceTokenDto
impl Send for AdminServiceTokenDto
impl Sync for AdminServiceTokenDto
impl Unpin for AdminServiceTokenDto
impl UnsafeUnpin for AdminServiceTokenDto
impl UnwindSafe for AdminServiceTokenDto