pub struct AdminServiceTokenListResponse {
pub items: Vec<AdminServiceTokenDto>,
}Expand description
Admin list response for admin service tokens.
Fields
items: Vec<AdminServiceTokenDto>Trait Implementations
Sourceimpl Clone for AdminServiceTokenListResponse
impl Clone for AdminServiceTokenListResponse
Sourcefn clone(&self) -> AdminServiceTokenListResponse
fn clone(&self) -> AdminServiceTokenListResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for AdminServiceTokenListResponse
impl<'de> Deserialize<'de> for AdminServiceTokenListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdminServiceTokenListResponse
impl JsonSchema for AdminServiceTokenListResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdminServiceTokenListResponse
impl RefUnwindSafe for AdminServiceTokenListResponse
impl Send for AdminServiceTokenListResponse
impl Sync for AdminServiceTokenListResponse
impl Unpin for AdminServiceTokenListResponse
impl UnsafeUnpin for AdminServiceTokenListResponse
impl UnwindSafe for AdminServiceTokenListResponse