pub struct CompleteHumanSetupRequest {
pub pioneer_code: PioneerCodeInput,
}Expand description
Browser-submitted request to finish setup for a signed-in human.
Fields
pioneer_code: PioneerCodeInputTrait Implementations
Sourceimpl Clone for CompleteHumanSetupRequest
impl Clone for CompleteHumanSetupRequest
Sourcefn clone(&self) -> CompleteHumanSetupRequest
fn clone(&self) -> CompleteHumanSetupRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompleteHumanSetupRequest
impl Debug for CompleteHumanSetupRequest
Sourceimpl<'de> Deserialize<'de> for CompleteHumanSetupRequest
impl<'de> Deserialize<'de> for CompleteHumanSetupRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CompleteHumanSetupRequest
impl JsonSchema for CompleteHumanSetupRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Validate for CompleteHumanSetupRequest
impl Validate for CompleteHumanSetupRequest
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for CompleteHumanSetupRequest
impl RefUnwindSafe for CompleteHumanSetupRequest
impl Send for CompleteHumanSetupRequest
impl Sync for CompleteHumanSetupRequest
impl Unpin for CompleteHumanSetupRequest
impl UnsafeUnpin for CompleteHumanSetupRequest
impl UnwindSafe for CompleteHumanSetupRequest