pub struct CompleteHumanSetupResponse {
pub session: HumanSessionResponse,
}Expand description
Response returned after finishing human account setup.
Fields
session: HumanSessionResponseTrait Implementations
Sourceimpl Clone for CompleteHumanSetupResponse
impl Clone for CompleteHumanSetupResponse
Sourcefn clone(&self) -> CompleteHumanSetupResponse
fn clone(&self) -> CompleteHumanSetupResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompleteHumanSetupResponse
impl Debug for CompleteHumanSetupResponse
Sourceimpl<'de> Deserialize<'de> for CompleteHumanSetupResponse
impl<'de> Deserialize<'de> for CompleteHumanSetupResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CompleteHumanSetupResponse
impl JsonSchema for CompleteHumanSetupResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CompleteHumanSetupResponse
impl RefUnwindSafe for CompleteHumanSetupResponse
impl Send for CompleteHumanSetupResponse
impl Sync for CompleteHumanSetupResponse
impl Unpin for CompleteHumanSetupResponse
impl UnsafeUnpin for CompleteHumanSetupResponse
impl UnwindSafe for CompleteHumanSetupResponse