pub struct CreateCreatorApiTokenRequest {
pub label: String,
pub expires_at: Option<String>,
}Expand description
Browser-submitted request to create a creator API token.
Fields
label: Stringexpires_at: Option<String>Trait Implementations
Sourceimpl Clone for CreateCreatorApiTokenRequest
impl Clone for CreateCreatorApiTokenRequest
Sourcefn clone(&self) -> CreateCreatorApiTokenRequest
fn clone(&self) -> CreateCreatorApiTokenRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateCreatorApiTokenRequest
impl Debug for CreateCreatorApiTokenRequest
Sourceimpl<'de> Deserialize<'de> for CreateCreatorApiTokenRequest
impl<'de> Deserialize<'de> for CreateCreatorApiTokenRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateCreatorApiTokenRequest
impl JsonSchema for CreateCreatorApiTokenRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Validate for CreateCreatorApiTokenRequest
impl Validate for CreateCreatorApiTokenRequest
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for CreateCreatorApiTokenRequest
impl RefUnwindSafe for CreateCreatorApiTokenRequest
impl Send for CreateCreatorApiTokenRequest
impl Sync for CreateCreatorApiTokenRequest
impl Unpin for CreateCreatorApiTokenRequest
impl UnsafeUnpin for CreateCreatorApiTokenRequest
impl UnwindSafe for CreateCreatorApiTokenRequest