pub struct GithubSignInCallbackRequest {
pub code: String,
pub state: String,
}Expand description
Browser-submitted request that completes GitHub sign-in.
Fields
code: Stringstate: StringTrait Implementations
Sourceimpl Clone for GithubSignInCallbackRequest
impl Clone for GithubSignInCallbackRequest
Sourcefn clone(&self) -> GithubSignInCallbackRequest
fn clone(&self) -> GithubSignInCallbackRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GithubSignInCallbackRequest
impl Debug for GithubSignInCallbackRequest
Sourceimpl<'de> Deserialize<'de> for GithubSignInCallbackRequest
impl<'de> Deserialize<'de> for GithubSignInCallbackRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GithubSignInCallbackRequest
impl JsonSchema for GithubSignInCallbackRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Validate for GithubSignInCallbackRequest
impl Validate for GithubSignInCallbackRequest
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for GithubSignInCallbackRequest
impl RefUnwindSafe for GithubSignInCallbackRequest
impl Send for GithubSignInCallbackRequest
impl Sync for GithubSignInCallbackRequest
impl Unpin for GithubSignInCallbackRequest
impl UnsafeUnpin for GithubSignInCallbackRequest
impl UnwindSafe for GithubSignInCallbackRequest