pub struct GithubSignInLoginRequest {
pub return_to: Option<String>,
}Expand description
Browser-submitted request to start GitHub sign-in.
Fields
return_to: Option<String>Trait Implementations
Sourceimpl Clone for GithubSignInLoginRequest
impl Clone for GithubSignInLoginRequest
Sourcefn clone(&self) -> GithubSignInLoginRequest
fn clone(&self) -> GithubSignInLoginRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GithubSignInLoginRequest
impl Debug for GithubSignInLoginRequest
Sourceimpl<'de> Deserialize<'de> for GithubSignInLoginRequest
impl<'de> Deserialize<'de> for GithubSignInLoginRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GithubSignInLoginRequest
impl JsonSchema for GithubSignInLoginRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Validate for GithubSignInLoginRequest
impl Validate for GithubSignInLoginRequest
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for GithubSignInLoginRequest
impl RefUnwindSafe for GithubSignInLoginRequest
impl Send for GithubSignInLoginRequest
impl Sync for GithubSignInLoginRequest
impl Unpin for GithubSignInLoginRequest
impl UnsafeUnpin for GithubSignInLoginRequest
impl UnwindSafe for GithubSignInLoginRequest