pub struct HumanSessionResponse {
pub human_id: HumanId,
pub status: HumanStatus,
pub github_user_id: GithubUserId,
pub github_login: String,
pub roles: Vec<HumanRole>,
pub csrf_token: String,
pub expires_at: String,
}Expand description
Current human browser session identity.
Fields
human_id: HumanIdstatus: HumanStatusgithub_user_id: GithubUserIdgithub_login: Stringroles: Vec<HumanRole>csrf_token: Stringexpires_at: StringTrait Implementations
Sourceimpl Clone for HumanSessionResponse
impl Clone for HumanSessionResponse
Sourcefn clone(&self) -> HumanSessionResponse
fn clone(&self) -> HumanSessionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HumanSessionResponse
impl Debug for HumanSessionResponse
Sourceimpl<'de> Deserialize<'de> for HumanSessionResponse
impl<'de> Deserialize<'de> for HumanSessionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HumanSessionResponse
impl JsonSchema for HumanSessionResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HumanSessionResponse
impl RefUnwindSafe for HumanSessionResponse
impl Send for HumanSessionResponse
impl Sync for HumanSessionResponse
impl Unpin for HumanSessionResponse
impl UnsafeUnpin for HumanSessionResponse
impl UnwindSafe for HumanSessionResponse