pub struct RevokeAdminServiceTokenResponse {
pub token_record: AdminServiceTokenDto,
}Expand description
Response returned after revoking an admin service token.
Fields
token_record: AdminServiceTokenDtoTrait Implementations
Sourceimpl Clone for RevokeAdminServiceTokenResponse
impl Clone for RevokeAdminServiceTokenResponse
Sourcefn clone(&self) -> RevokeAdminServiceTokenResponse
fn clone(&self) -> RevokeAdminServiceTokenResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RevokeAdminServiceTokenResponse
impl<'de> Deserialize<'de> for RevokeAdminServiceTokenResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RevokeAdminServiceTokenResponse
impl JsonSchema for RevokeAdminServiceTokenResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RevokeAdminServiceTokenResponse
impl RefUnwindSafe for RevokeAdminServiceTokenResponse
impl Send for RevokeAdminServiceTokenResponse
impl Sync for RevokeAdminServiceTokenResponse
impl Unpin for RevokeAdminServiceTokenResponse
impl UnsafeUnpin for RevokeAdminServiceTokenResponse
impl UnwindSafe for RevokeAdminServiceTokenResponse