pub struct RevokeCreatorApiTokenResponse {
pub token_record: CreatorApiTokenDto,
}Expand description
Response returned after revoking a creator API token.
Fields
token_record: CreatorApiTokenDtoTrait Implementations
Sourceimpl Clone for RevokeCreatorApiTokenResponse
impl Clone for RevokeCreatorApiTokenResponse
Sourcefn clone(&self) -> RevokeCreatorApiTokenResponse
fn clone(&self) -> RevokeCreatorApiTokenResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RevokeCreatorApiTokenResponse
impl<'de> Deserialize<'de> for RevokeCreatorApiTokenResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RevokeCreatorApiTokenResponse
impl JsonSchema for RevokeCreatorApiTokenResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RevokeCreatorApiTokenResponse
impl RefUnwindSafe for RevokeCreatorApiTokenResponse
impl Send for RevokeCreatorApiTokenResponse
impl Sync for RevokeCreatorApiTokenResponse
impl Unpin for RevokeCreatorApiTokenResponse
impl UnsafeUnpin for RevokeCreatorApiTokenResponse
impl UnwindSafe for RevokeCreatorApiTokenResponse