pub enum ChallengeExecutionSpec {
SeparatedEvaluator(SeparatedEvaluatorExecutionSpec),
PipedStdio(PipedStdioExecutionSpec),
CoexecutedBenchmark(CoexecutedBenchmarkExecutionSpec),
}Expand description
Challenge-owned execution topology and run manifest locations for zip_project.
Variants
SeparatedEvaluator(SeparatedEvaluatorExecutionSpec)
PipedStdio(PipedStdioExecutionSpec)
CoexecutedBenchmark(CoexecutedBenchmarkExecutionSpec)
Implementations
Sourceimpl ChallengeExecutionSpec
impl ChallengeExecutionSpec
Sourcepub fn mode(&self) -> ChallengeExecutionMode
pub fn mode(&self) -> ChallengeExecutionMode
Return the current execution topology mode.
Sourcepub fn piped_stdio(&self) -> Option<&PipedStdioExecutionSpec>
pub fn piped_stdio(&self) -> Option<&PipedStdioExecutionSpec>
Borrow the current piped-stdio execution contract.
Sourcepub fn coexecuted_benchmark(&self) -> Option<&CoexecutedBenchmarkExecutionSpec>
pub fn coexecuted_benchmark(&self) -> Option<&CoexecutedBenchmarkExecutionSpec>
Borrow the current coexecuted-evaluator contract.
Sourcepub fn trusted_evaluator(&self) -> &EvaluatorSpec
pub fn trusted_evaluator(&self) -> &EvaluatorSpec
Borrow the trusted evaluator command contract for the current topology.
Sourcepub fn validation_runs(&self) -> Option<&BundleRelativePath>
pub fn validation_runs(&self) -> Option<&BundleRelativePath>
Borrow public validation run locator if declared.
Sourcepub fn validation_setup(&self) -> Option<&ChallengeSetupSpec>
pub fn validation_setup(&self) -> Option<&ChallengeSetupSpec>
Borrow public validation setup contract if declared.
Sourcepub fn official_runs(&self) -> Option<&BundleRelativePath>
pub fn official_runs(&self) -> Option<&BundleRelativePath>
Borrow official benchmark run locator if declared.
Sourcepub fn official_evaluation_setup(&self) -> Option<&ChallengeSetupSpec>
pub fn official_evaluation_setup(&self) -> Option<&ChallengeSetupSpec>
Borrow official benchmark setup contract if declared.
Sourcepub fn has_official_evaluation_setup(&self) -> bool
pub fn has_official_evaluation_setup(&self) -> bool
Return whether the official evaluator declares setup-generated official inputs.