pub struct AdminChallengeListResponse {
pub items: Vec<AdminChallengeListItemDto>,
}Expand description
Admin challenge list response.
Fields
items: Vec<AdminChallengeListItemDto>Trait Implementations
Sourceimpl Clone for AdminChallengeListResponse
impl Clone for AdminChallengeListResponse
Sourcefn clone(&self) -> AdminChallengeListResponse
fn clone(&self) -> AdminChallengeListResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminChallengeListResponse
impl Debug for AdminChallengeListResponse
Sourceimpl<'de> Deserialize<'de> for AdminChallengeListResponse
impl<'de> Deserialize<'de> for AdminChallengeListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdminChallengeListResponse
impl JsonSchema for AdminChallengeListResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdminChallengeListResponse
impl RefUnwindSafe for AdminChallengeListResponse
impl Send for AdminChallengeListResponse
impl Sync for AdminChallengeListResponse
impl Unpin for AdminChallengeListResponse
impl UnsafeUnpin for AdminChallengeListResponse
impl UnwindSafe for AdminChallengeListResponse