pub struct ChallengeAdminResponse {
pub challenge_name: ChallengeName,
pub title: String,
pub summary: LocalizedText,
pub keywords: Vec<ChallengeKeyword>,
pub status: ChallengeLifecycleStatus,
pub created_at: String,
pub updated_at: String,
}Expand description
Admin-facing challenge metadata response.
Fields
challenge_name: ChallengeNametitle: Stringsummary: LocalizedTextkeywords: Vec<ChallengeKeyword>status: ChallengeLifecycleStatuscreated_at: Stringupdated_at: StringTrait Implementations
Sourceimpl Clone for ChallengeAdminResponse
impl Clone for ChallengeAdminResponse
Sourcefn clone(&self) -> ChallengeAdminResponse
fn clone(&self) -> ChallengeAdminResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChallengeAdminResponse
impl Debug for ChallengeAdminResponse
Sourceimpl<'de> Deserialize<'de> for ChallengeAdminResponse
impl<'de> Deserialize<'de> for ChallengeAdminResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChallengeAdminResponse
impl JsonSchema for ChallengeAdminResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChallengeAdminResponse
impl RefUnwindSafe for ChallengeAdminResponse
impl Send for ChallengeAdminResponse
impl Sync for ChallengeAdminResponse
impl Unpin for ChallengeAdminResponse
impl UnsafeUnpin for ChallengeAdminResponse
impl UnwindSafe for ChallengeAdminResponse