pub struct ChallengeListResponse {
pub items: Vec<ChallengeListItemDto>,
pub total_count: i64,
pub limit: i64,
pub offset: i64,
pub has_more: bool,
}Expand description
Public challenge catalog response.
Fields
items: Vec<ChallengeListItemDto>total_count: i64limit: i64offset: i64has_more: boolTrait Implementations
Sourceimpl Clone for ChallengeListResponse
impl Clone for ChallengeListResponse
Sourcefn clone(&self) -> ChallengeListResponse
fn clone(&self) -> ChallengeListResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChallengeListResponse
impl Debug for ChallengeListResponse
Sourceimpl<'de> Deserialize<'de> for ChallengeListResponse
impl<'de> Deserialize<'de> for ChallengeListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChallengeListResponse
impl JsonSchema for ChallengeListResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChallengeListResponse
impl RefUnwindSafe for ChallengeListResponse
impl Send for ChallengeListResponse
impl Sync for ChallengeListResponse
impl Unpin for ChallengeListResponse
impl UnsafeUnpin for ChallengeListResponse
impl UnwindSafe for ChallengeListResponse