pub struct ChallengeRunInputFile {
pub path: RunInputPath,
pub source_path: Option<BundleRelativePath>,
pub content: Option<String>,
pub content_json: Option<Value>,
}Expand description
One input file materialized into AGENTICS_INPUT_DIR for a file-mode run.
Fields
path: RunInputPathsource_path: Option<BundleRelativePath>content: Option<String>content_json: Option<Value>Trait Implementations
Sourceimpl Clone for ChallengeRunInputFile
impl Clone for ChallengeRunInputFile
Sourcefn clone(&self) -> ChallengeRunInputFile
fn clone(&self) -> ChallengeRunInputFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChallengeRunInputFile
impl Debug for ChallengeRunInputFile
Sourceimpl<'de> Deserialize<'de> for ChallengeRunInputFile
impl<'de> Deserialize<'de> for ChallengeRunInputFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChallengeRunInputFile
impl JsonSchema for ChallengeRunInputFile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChallengeRunInputFile
impl RefUnwindSafe for ChallengeRunInputFile
impl Send for ChallengeRunInputFile
impl Sync for ChallengeRunInputFile
impl Unpin for ChallengeRunInputFile
impl UnsafeUnpin for ChallengeRunInputFile
impl UnwindSafe for ChallengeRunInputFile