pub struct ChallengeTargetSpec {
pub name: TargetName,
pub docker_platform: DockerPlatform,
pub accelerator: TargetAccelerator,
pub validation_enabled: bool,
pub resource_profile: ResourceProfileSpec,
}Expand description
One execution and ranking target declared by a challenge.
Fields
name: TargetNamedocker_platform: DockerPlatformaccelerator: TargetAcceleratorRequired nullable field: JSON null means no accelerator, “gpu” means GPU acceleration.
validation_enabled: boolresource_profile: ResourceProfileSpecTrait Implementations
Sourceimpl Clone for ChallengeTargetSpec
impl Clone for ChallengeTargetSpec
Sourcefn clone(&self) -> ChallengeTargetSpec
fn clone(&self) -> ChallengeTargetSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChallengeTargetSpec
impl Debug for ChallengeTargetSpec
Sourceimpl<'de> Deserialize<'de> for ChallengeTargetSpec
impl<'de> Deserialize<'de> for ChallengeTargetSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChallengeTargetSpec
impl JsonSchema for ChallengeTargetSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChallengeTargetSpec
impl RefUnwindSafe for ChallengeTargetSpec
impl Send for ChallengeTargetSpec
impl Sync for ChallengeTargetSpec
impl Unpin for ChallengeTargetSpec
impl UnsafeUnpin for ChallengeTargetSpec
impl UnwindSafe for ChallengeTargetSpec