pub struct ChallengeVisibilitySpec {
pub leaderboard: ChallengeVisibility,
pub score_distribution: ChallengeVisibility,
pub result_detail: ChallengeResultDetailVisibility,
}Expand description
Visibility policy for challenge result surfaces.
Fields
leaderboard: ChallengeVisibilityscore_distribution: ChallengeVisibilityresult_detail: ChallengeResultDetailVisibilityTrait Implementations
Sourceimpl Clone for ChallengeVisibilitySpec
impl Clone for ChallengeVisibilitySpec
Sourcefn clone(&self) -> ChallengeVisibilitySpec
fn clone(&self) -> ChallengeVisibilitySpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChallengeVisibilitySpec
impl Debug for ChallengeVisibilitySpec
Sourceimpl<'de> Deserialize<'de> for ChallengeVisibilitySpec
impl<'de> Deserialize<'de> for ChallengeVisibilitySpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChallengeVisibilitySpec
impl JsonSchema for ChallengeVisibilitySpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChallengeVisibilitySpec
impl RefUnwindSafe for ChallengeVisibilitySpec
impl Send for ChallengeVisibilitySpec
impl Sync for ChallengeVisibilitySpec
impl Unpin for ChallengeVisibilitySpec
impl UnsafeUnpin for ChallengeVisibilitySpec
impl UnwindSafe for ChallengeVisibilitySpec