pub struct CoexecutedBenchmarkExecutionSpec {
pub coexecuted_evaluator: EvaluatorSpec,
pub acknowledge_danger: bool,
pub validation_setup: Option<CoexecutedBenchmarkSetupSpec>,
pub official_evaluation_setup: Option<CoexecutedBenchmarkSetupSpec>,
}Expand description
Coexecuted topology where a trusted coexecuted-evaluator imports participant code in one container.
Fields
coexecuted_evaluator: EvaluatorSpecacknowledge_danger: boolvalidation_setup: Option<CoexecutedBenchmarkSetupSpec>official_evaluation_setup: Option<CoexecutedBenchmarkSetupSpec>Trait Implementations
Sourceimpl Clone for CoexecutedBenchmarkExecutionSpec
impl Clone for CoexecutedBenchmarkExecutionSpec
Sourcefn clone(&self) -> CoexecutedBenchmarkExecutionSpec
fn clone(&self) -> CoexecutedBenchmarkExecutionSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CoexecutedBenchmarkExecutionSpec
impl<'de> Deserialize<'de> for CoexecutedBenchmarkExecutionSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CoexecutedBenchmarkExecutionSpec
impl JsonSchema for CoexecutedBenchmarkExecutionSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CoexecutedBenchmarkExecutionSpec
impl RefUnwindSafe for CoexecutedBenchmarkExecutionSpec
impl Send for CoexecutedBenchmarkExecutionSpec
impl Sync for CoexecutedBenchmarkExecutionSpec
impl Unpin for CoexecutedBenchmarkExecutionSpec
impl UnsafeUnpin for CoexecutedBenchmarkExecutionSpec
impl UnwindSafe for CoexecutedBenchmarkExecutionSpec