pub struct HardwareProfileSpec {
pub kind: String,
pub gpu_model: Option<String>,
pub gpu_count: Option<u32>,
pub gpu_memory_gb: Option<u64>,
pub cuda_variant: Option<String>,
pub cuda_version: Option<String>,
pub driver_minimum: Option<String>,
}Expand description
Optional hardware metadata advertised with a resource profile.
Fields
kind: Stringgpu_model: Option<String>gpu_count: Option<u32>gpu_memory_gb: Option<u64>cuda_variant: Option<String>cuda_version: Option<String>driver_minimum: Option<String>Trait Implementations
Sourceimpl Clone for HardwareProfileSpec
impl Clone for HardwareProfileSpec
Sourcefn clone(&self) -> HardwareProfileSpec
fn clone(&self) -> HardwareProfileSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HardwareProfileSpec
impl Debug for HardwareProfileSpec
Sourceimpl<'de> Deserialize<'de> for HardwareProfileSpec
impl<'de> Deserialize<'de> for HardwareProfileSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HardwareProfileSpec
impl JsonSchema for HardwareProfileSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for HardwareProfileSpec
impl Serialize for HardwareProfileSpec
Sourceimpl Validate for HardwareProfileSpec
impl Validate for HardwareProfileSpec
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for HardwareProfileSpec
impl RefUnwindSafe for HardwareProfileSpec
impl Send for HardwareProfileSpec
impl Sync for HardwareProfileSpec
impl Unpin for HardwareProfileSpec
impl UnsafeUnpin for HardwareProfileSpec
impl UnwindSafe for HardwareProfileSpec