pub struct PipedStdioExecutionSpec {
pub interactive_evaluator: EvaluatorSpec,
pub acknowledge_stdio_protocol_framing: bool,
pub validation_session: Option<BundleRelativePath>,
pub validation_setup: Option<PipedStdioSetupSpec>,
pub official_session: Option<BundleRelativePath>,
pub official_evaluation_setup: Option<PipedStdioSetupSpec>,
}Expand description
Interactive topology where a trusted interactive-evaluator exchanges stdio with one solution run.
Fields
interactive_evaluator: EvaluatorSpecacknowledge_stdio_protocol_framing: boolvalidation_session: Option<BundleRelativePath>validation_setup: Option<PipedStdioSetupSpec>official_session: Option<BundleRelativePath>official_evaluation_setup: Option<PipedStdioSetupSpec>Trait Implementations
Sourceimpl Clone for PipedStdioExecutionSpec
impl Clone for PipedStdioExecutionSpec
Sourcefn clone(&self) -> PipedStdioExecutionSpec
fn clone(&self) -> PipedStdioExecutionSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PipedStdioExecutionSpec
impl Debug for PipedStdioExecutionSpec
Sourceimpl<'de> Deserialize<'de> for PipedStdioExecutionSpec
impl<'de> Deserialize<'de> for PipedStdioExecutionSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PipedStdioExecutionSpec
impl JsonSchema for PipedStdioExecutionSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PipedStdioExecutionSpec
impl RefUnwindSafe for PipedStdioExecutionSpec
impl Send for PipedStdioExecutionSpec
impl Sync for PipedStdioExecutionSpec
impl Unpin for PipedStdioExecutionSpec
impl UnsafeUnpin for PipedStdioExecutionSpec
impl UnwindSafe for PipedStdioExecutionSpec