pub struct PipedStdioSetupSpec {
pub command: Vec<String>,
pub result_session_file: BundleRelativePath,
pub reproducibility_notes: Option<String>,
}Expand description
Optional interactive-evaluator command that sets up one generated interactive session.
Fields
command: Vec<String>result_session_file: BundleRelativePathRelative path, under the setup workspace, to the generated session manifest.
reproducibility_notes: Option<String>Challenge-owner notes about seeds, versions, or external data provenance.