pub struct PublicCoexecutedBenchmarkExecutionSpec {
pub coexecuted_evaluator: EvaluatorSpec,
pub acknowledge_danger: bool,
pub validation_setup: Option<CoexecutedBenchmarkSetupSpec>,
}Expand description
Public coexecuted-evaluator topology metadata.
Fields
coexecuted_evaluator: EvaluatorSpecacknowledge_danger: boolvalidation_setup: Option<CoexecutedBenchmarkSetupSpec>Trait Implementations
Sourceimpl Clone for PublicCoexecutedBenchmarkExecutionSpec
impl Clone for PublicCoexecutedBenchmarkExecutionSpec
Sourcefn clone(&self) -> PublicCoexecutedBenchmarkExecutionSpec
fn clone(&self) -> PublicCoexecutedBenchmarkExecutionSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PublicCoexecutedBenchmarkExecutionSpec
impl<'de> Deserialize<'de> for PublicCoexecutedBenchmarkExecutionSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PublicCoexecutedBenchmarkExecutionSpec
impl JsonSchema for PublicCoexecutedBenchmarkExecutionSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PublicCoexecutedBenchmarkExecutionSpec
impl RefUnwindSafe for PublicCoexecutedBenchmarkExecutionSpec
impl Send for PublicCoexecutedBenchmarkExecutionSpec
impl Sync for PublicCoexecutedBenchmarkExecutionSpec
impl Unpin for PublicCoexecutedBenchmarkExecutionSpec
impl UnsafeUnpin for PublicCoexecutedBenchmarkExecutionSpec
impl UnwindSafe for PublicCoexecutedBenchmarkExecutionSpec