pub struct ResourceProfileSpec {
pub name: ResourceProfileName,
pub resource_description: Option<String>,
pub solution_image: ChallengeImageReference,
pub evaluator_image: ChallengeImageReference,
pub solution: SolutionStageProfiles,
pub evaluator: EvaluatorStageProfiles,
pub hardware_metadata: Option<HardwareProfileSpec>,
}Expand description
Resource envelope and Docker images declared by a challenge.
Fields
name: ResourceProfileNameresource_description: Option<String>solution_image: ChallengeImageReferenceevaluator_image: ChallengeImageReferencesolution: SolutionStageProfilesevaluator: EvaluatorStageProfileshardware_metadata: Option<HardwareProfileSpec>Trait Implementations
Sourceimpl Clone for ResourceProfileSpec
impl Clone for ResourceProfileSpec
Sourcefn clone(&self) -> ResourceProfileSpec
fn clone(&self) -> ResourceProfileSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResourceProfileSpec
impl Debug for ResourceProfileSpec
Sourceimpl<'de> Deserialize<'de> for ResourceProfileSpec
impl<'de> Deserialize<'de> for ResourceProfileSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResourceProfileSpec
impl JsonSchema for ResourceProfileSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ResourceProfileSpec
impl Serialize for ResourceProfileSpec
Sourceimpl Validate for ResourceProfileSpec
impl Validate for ResourceProfileSpec
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for ResourceProfileSpec
impl RefUnwindSafe for ResourceProfileSpec
impl Send for ResourceProfileSpec
impl Sync for ResourceProfileSpec
impl Unpin for ResourceProfileSpec
impl UnsafeUnpin for ResourceProfileSpec
impl UnwindSafe for ResourceProfileSpec