pub struct SolutionSpec {
pub protocol: String,
pub manifest_file: BundleRelativePath,
}Expand description
Local solution format constraints declared by a bundle.
Fields
protocol: Stringmanifest_file: BundleRelativePathTrait Implementations
Sourceimpl Clone for SolutionSpec
impl Clone for SolutionSpec
Sourcefn clone(&self) -> SolutionSpec
fn clone(&self) -> SolutionSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SolutionSpec
impl Debug for SolutionSpec
Sourceimpl<'de> Deserialize<'de> for SolutionSpec
impl<'de> Deserialize<'de> for SolutionSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SolutionSpec
impl JsonSchema for SolutionSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SolutionSpec
impl RefUnwindSafe for SolutionSpec
impl Send for SolutionSpec
impl Sync for SolutionSpec
impl Unpin for SolutionSpec
impl UnsafeUnpin for SolutionSpec
impl UnwindSafe for SolutionSpec