pub struct StageResourceProfile {
pub timeout_sec: u64,
pub memory_limit_mb: u64,
pub cpu_limit_millis: u32,
pub disk_limit_mb: u64,
pub network_access: ZipProjectNetworkAccess,
}Expand description
Resource envelope for one Docker-executed stage.
Fields
timeout_sec: u64memory_limit_mb: u64cpu_limit_millis: u32disk_limit_mb: u64network_access: ZipProjectNetworkAccessTrait Implementations
Sourceimpl Clone for StageResourceProfile
impl Clone for StageResourceProfile
Sourcefn clone(&self) -> StageResourceProfile
fn clone(&self) -> StageResourceProfile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StageResourceProfile
impl Debug for StageResourceProfile
Sourceimpl<'de> Deserialize<'de> for StageResourceProfile
impl<'de> Deserialize<'de> for StageResourceProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StageResourceProfile
impl JsonSchema for StageResourceProfile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for StageResourceProfile
impl Serialize for StageResourceProfile
Sourceimpl Validate for StageResourceProfile
impl Validate for StageResourceProfile
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for StageResourceProfile
impl RefUnwindSafe for StageResourceProfile
impl Send for StageResourceProfile
impl Sync for StageResourceProfile
impl Unpin for StageResourceProfile
impl UnsafeUnpin for StageResourceProfile
impl UnwindSafe for StageResourceProfile