pub struct ChallengeArchiveRequestSpec {
pub reason: String,
}Expand description
Public archive request metadata.
Fields
reason: StringTrait Implementations
Sourceimpl Clone for ChallengeArchiveRequestSpec
impl Clone for ChallengeArchiveRequestSpec
Sourcefn clone(&self) -> ChallengeArchiveRequestSpec
fn clone(&self) -> ChallengeArchiveRequestSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChallengeArchiveRequestSpec
impl Debug for ChallengeArchiveRequestSpec
Sourceimpl<'de> Deserialize<'de> for ChallengeArchiveRequestSpec
impl<'de> Deserialize<'de> for ChallengeArchiveRequestSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChallengeArchiveRequestSpec
impl JsonSchema for ChallengeArchiveRequestSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChallengeArchiveRequestSpec
impl RefUnwindSafe for ChallengeArchiveRequestSpec
impl Send for ChallengeArchiveRequestSpec
impl Sync for ChallengeArchiveRequestSpec
impl Unpin for ChallengeArchiveRequestSpec
impl UnsafeUnpin for ChallengeArchiveRequestSpec
impl UnwindSafe for ChallengeArchiveRequestSpec