pub struct ChallengeReviewRecordCleanupResponse {
pub abandoned_review_records: i64,
pub purged_private_assets: i64,
pub purged_temporary_storage_objects: i64,
}Expand description
Admin response returned after abandoning stale review records and deleting purge-eligible unpublished private asset records.
Fields
abandoned_review_records: i64purged_private_assets: i64purged_temporary_storage_objects: i64Trait Implementations
Sourceimpl Clone for ChallengeReviewRecordCleanupResponse
impl Clone for ChallengeReviewRecordCleanupResponse
Sourcefn clone(&self) -> ChallengeReviewRecordCleanupResponse
fn clone(&self) -> ChallengeReviewRecordCleanupResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ChallengeReviewRecordCleanupResponse
impl<'de> Deserialize<'de> for ChallengeReviewRecordCleanupResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChallengeReviewRecordCleanupResponse
impl JsonSchema for ChallengeReviewRecordCleanupResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChallengeReviewRecordCleanupResponse
impl RefUnwindSafe for ChallengeReviewRecordCleanupResponse
impl Send for ChallengeReviewRecordCleanupResponse
impl Sync for ChallengeReviewRecordCleanupResponse
impl Unpin for ChallengeReviewRecordCleanupResponse
impl UnsafeUnpin for ChallengeReviewRecordCleanupResponse
impl UnwindSafe for ChallengeReviewRecordCleanupResponse