pub struct CreateChallengeReviewRecordRequest {
pub repo_url: GithubRepoRemote,
pub pr_number: GithubPullRequestNumber,
pub pr_url: GithubPullRequestUrl,
pub commit_sha: GitCommitSha,
pub challenge_path: RepoRelativePath,
pub pr_author_github_user_id: GithubUserId,
pub manifest: ChallengeCreationManifest,
}Expand description
Creator-authenticated request for registering a public GitHub PR for review.
Fields
repo_url: GithubRepoRemotepr_number: GithubPullRequestNumberpr_url: GithubPullRequestUrlcommit_sha: GitCommitShachallenge_path: RepoRelativePathmanifest: ChallengeCreationManifestTrait Implementations
Sourceimpl Clone for CreateChallengeReviewRecordRequest
impl Clone for CreateChallengeReviewRecordRequest
Sourcefn clone(&self) -> CreateChallengeReviewRecordRequest
fn clone(&self) -> CreateChallengeReviewRecordRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CreateChallengeReviewRecordRequest
impl<'de> Deserialize<'de> for CreateChallengeReviewRecordRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateChallengeReviewRecordRequest
impl JsonSchema for CreateChallengeReviewRecordRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Validate for CreateChallengeReviewRecordRequest
impl Validate for CreateChallengeReviewRecordRequest
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for CreateChallengeReviewRecordRequest
impl RefUnwindSafe for CreateChallengeReviewRecordRequest
impl Send for CreateChallengeReviewRecordRequest
impl Sync for CreateChallengeReviewRecordRequest
impl Unpin for CreateChallengeReviewRecordRequest
impl UnsafeUnpin for CreateChallengeReviewRecordRequest
impl UnwindSafe for CreateChallengeReviewRecordRequest