pub struct ValidateChallengeReviewRecordRequest {
pub repository_path: String,
}Expand description
Admin payload for validating a review record against a checked-out repository path.
Fields
repository_path: StringTrait Implementations
Sourceimpl Clone for ValidateChallengeReviewRecordRequest
impl Clone for ValidateChallengeReviewRecordRequest
Sourcefn clone(&self) -> ValidateChallengeReviewRecordRequest
fn clone(&self) -> ValidateChallengeReviewRecordRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ValidateChallengeReviewRecordRequest
impl<'de> Deserialize<'de> for ValidateChallengeReviewRecordRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ValidateChallengeReviewRecordRequest
impl JsonSchema for ValidateChallengeReviewRecordRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Validate for ValidateChallengeReviewRecordRequest
impl Validate for ValidateChallengeReviewRecordRequest
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for ValidateChallengeReviewRecordRequest
impl RefUnwindSafe for ValidateChallengeReviewRecordRequest
impl Send for ValidateChallengeReviewRecordRequest
impl Sync for ValidateChallengeReviewRecordRequest
impl Unpin for ValidateChallengeReviewRecordRequest
impl UnsafeUnpin for ValidateChallengeReviewRecordRequest
impl UnwindSafe for ValidateChallengeReviewRecordRequest