pub struct EvaluationJobPayload {
pub artifact_key: StorageKey,
pub bundle_key: StorageKey,
pub public_bundle_key: StorageKey,
pub challenge_name: ChallengeName,
pub target: TargetName,
}Expand description
Runner payload persisted on an evaluation job.
Fields
artifact_key: StorageKeybundle_key: StorageKeypublic_bundle_key: StorageKeychallenge_name: ChallengeNametarget: TargetNameTrait Implementations
Sourceimpl Clone for EvaluationJobPayload
impl Clone for EvaluationJobPayload
Sourcefn clone(&self) -> EvaluationJobPayload
fn clone(&self) -> EvaluationJobPayload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvaluationJobPayload
impl Debug for EvaluationJobPayload
Sourceimpl<'de> Deserialize<'de> for EvaluationJobPayload
impl<'de> Deserialize<'de> for EvaluationJobPayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvaluationJobPayload
impl JsonSchema for EvaluationJobPayload
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EvaluationJobPayload
impl RefUnwindSafe for EvaluationJobPayload
impl Send for EvaluationJobPayload
impl Sync for EvaluationJobPayload
impl Unpin for EvaluationJobPayload
impl UnsafeUnpin for EvaluationJobPayload
impl UnwindSafe for EvaluationJobPayload