pub struct LocalAgenticsImageReference { /* private fields */ }Expand description
Development-only Docker image reference for first-party Agentics local images.
Implementations
Sourceimpl LocalAgenticsImageReference
impl LocalAgenticsImageReference
Sourcepub fn try_new(
value: impl AsRef<str>,
) -> Result<Self, LocalAgenticsImageReferenceError>
pub fn try_new( value: impl AsRef<str>, ) -> Result<Self, LocalAgenticsImageReferenceError>
Parse and validate a supported local Agentics Docker image reference.
Sourcepub fn repository(&self) -> &str
pub fn repository(&self) -> &str
Borrow the local repository name used by Agentics image-family policy checks.