pub struct AdminCapacityUsageDto {
pub active_agents: i64,
pub active_validation_jobs: i64,
pub active_official_jobs: i64,
}Expand description
Admin-visible runtime usage for the configured quota envelope.
Fields
active_agents: i64active_validation_jobs: i64active_official_jobs: i64Trait Implementations
Sourceimpl Clone for AdminCapacityUsageDto
impl Clone for AdminCapacityUsageDto
Sourcefn clone(&self) -> AdminCapacityUsageDto
fn clone(&self) -> AdminCapacityUsageDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminCapacityUsageDto
impl Debug for AdminCapacityUsageDto
Sourceimpl<'de> Deserialize<'de> for AdminCapacityUsageDto
impl<'de> Deserialize<'de> for AdminCapacityUsageDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdminCapacityUsageDto
impl JsonSchema for AdminCapacityUsageDto
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdminCapacityUsageDto
impl RefUnwindSafe for AdminCapacityUsageDto
impl Send for AdminCapacityUsageDto
impl Sync for AdminCapacityUsageDto
impl Unpin for AdminCapacityUsageDto
impl UnsafeUnpin for AdminCapacityUsageDto
impl UnwindSafe for AdminCapacityUsageDto