pub struct AdminServiceHeartbeatDto {
pub service_name: String,
pub last_seen_at: String,
pub payload: Value,
}Expand description
One service heartbeat row displayed in the admin operations console.
Fields
service_name: Stringlast_seen_at: Stringpayload: ValueTrait Implementations
Sourceimpl Clone for AdminServiceHeartbeatDto
impl Clone for AdminServiceHeartbeatDto
Sourcefn clone(&self) -> AdminServiceHeartbeatDto
fn clone(&self) -> AdminServiceHeartbeatDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminServiceHeartbeatDto
impl Debug for AdminServiceHeartbeatDto
Sourceimpl<'de> Deserialize<'de> for AdminServiceHeartbeatDto
impl<'de> Deserialize<'de> for AdminServiceHeartbeatDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdminServiceHeartbeatDto
impl JsonSchema for AdminServiceHeartbeatDto
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdminServiceHeartbeatDto
impl RefUnwindSafe for AdminServiceHeartbeatDto
impl Send for AdminServiceHeartbeatDto
impl Sync for AdminServiceHeartbeatDto
impl Unpin for AdminServiceHeartbeatDto
impl UnsafeUnpin for AdminServiceHeartbeatDto
impl UnwindSafe for AdminServiceHeartbeatDto