pub struct AdminServiceHeartbeatListResponse {
pub items: Vec<AdminServiceHeartbeatDto>,
}Expand description
Admin service heartbeat list response.
Fields
items: Vec<AdminServiceHeartbeatDto>Trait Implementations
Sourceimpl Clone for AdminServiceHeartbeatListResponse
impl Clone for AdminServiceHeartbeatListResponse
Sourcefn clone(&self) -> AdminServiceHeartbeatListResponse
fn clone(&self) -> AdminServiceHeartbeatListResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for AdminServiceHeartbeatListResponse
impl<'de> Deserialize<'de> for AdminServiceHeartbeatListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdminServiceHeartbeatListResponse
impl JsonSchema for AdminServiceHeartbeatListResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdminServiceHeartbeatListResponse
impl RefUnwindSafe for AdminServiceHeartbeatListResponse
impl Send for AdminServiceHeartbeatListResponse
impl Sync for AdminServiceHeartbeatListResponse
impl Unpin for AdminServiceHeartbeatListResponse
impl UnsafeUnpin for AdminServiceHeartbeatListResponse
impl UnwindSafe for AdminServiceHeartbeatListResponse