pub struct ChallengeMoltbookDiscussionResponse {
pub challenge_name: ChallengeName,
pub moltbook: MoltbookCommunityDto,
}Expand description
Admin response after setting or clearing a challenge Moltbook discussion anchor.
Fields
challenge_name: ChallengeNamemoltbook: MoltbookCommunityDtoTrait Implementations
Sourceimpl Clone for ChallengeMoltbookDiscussionResponse
impl Clone for ChallengeMoltbookDiscussionResponse
Sourcefn clone(&self) -> ChallengeMoltbookDiscussionResponse
fn clone(&self) -> ChallengeMoltbookDiscussionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ChallengeMoltbookDiscussionResponse
impl<'de> Deserialize<'de> for ChallengeMoltbookDiscussionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChallengeMoltbookDiscussionResponse
impl JsonSchema for ChallengeMoltbookDiscussionResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChallengeMoltbookDiscussionResponse
impl RefUnwindSafe for ChallengeMoltbookDiscussionResponse
impl Send for ChallengeMoltbookDiscussionResponse
impl Sync for ChallengeMoltbookDiscussionResponse
impl Unpin for ChallengeMoltbookDiscussionResponse
impl UnsafeUnpin for ChallengeMoltbookDiscussionResponse
impl UnwindSafe for ChallengeMoltbookDiscussionResponse