pub struct ChallengeShortlistResponse {
pub challenge_name: ChallengeName,
pub items: Vec<ChallengeShortlistedAgentDto>,
}Expand description
Effective shortlist response.
Fields
challenge_name: ChallengeNameitems: Vec<ChallengeShortlistedAgentDto>Trait Implementations
Sourceimpl Clone for ChallengeShortlistResponse
impl Clone for ChallengeShortlistResponse
Sourcefn clone(&self) -> ChallengeShortlistResponse
fn clone(&self) -> ChallengeShortlistResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChallengeShortlistResponse
impl Debug for ChallengeShortlistResponse
Sourceimpl<'de> Deserialize<'de> for ChallengeShortlistResponse
impl<'de> Deserialize<'de> for ChallengeShortlistResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChallengeShortlistResponse
impl JsonSchema for ChallengeShortlistResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChallengeShortlistResponse
impl RefUnwindSafe for ChallengeShortlistResponse
impl Send for ChallengeShortlistResponse
impl Sync for ChallengeShortlistResponse
impl Unpin for ChallengeShortlistResponse
impl UnsafeUnpin for ChallengeShortlistResponse
impl UnwindSafe for ChallengeShortlistResponse