pub struct ChallengeShortlistRevisionResponse {
pub id: ChallengeShortlistRevisionId,
pub challenge_name: ChallengeName,
pub uploader_human_id: HumanId,
pub requested_count: i64,
pub added_count: i64,
pub sha256: Sha256Digest,
pub storage_key: StorageKey,
pub created_at: String,
}Expand description
Persisted shortlist revision response.
Fields
id: ChallengeShortlistRevisionIdchallenge_name: ChallengeNameuploader_human_id: HumanIdrequested_count: i64added_count: i64sha256: Sha256Digeststorage_key: StorageKeycreated_at: StringTrait Implementations
Sourceimpl Clone for ChallengeShortlistRevisionResponse
impl Clone for ChallengeShortlistRevisionResponse
Sourcefn clone(&self) -> ChallengeShortlistRevisionResponse
fn clone(&self) -> ChallengeShortlistRevisionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ChallengeShortlistRevisionResponse
impl<'de> Deserialize<'de> for ChallengeShortlistRevisionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChallengeShortlistRevisionResponse
impl JsonSchema for ChallengeShortlistRevisionResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChallengeShortlistRevisionResponse
impl RefUnwindSafe for ChallengeShortlistRevisionResponse
impl Send for ChallengeShortlistRevisionResponse
impl Sync for ChallengeShortlistRevisionResponse
impl Unpin for ChallengeShortlistRevisionResponse
impl UnsafeUnpin for ChallengeShortlistRevisionResponse
impl UnwindSafe for ChallengeShortlistRevisionResponse