pub struct CreateChallengeShortlistRevisionRequest {
pub agent_ids_to_add: Vec<AgentId>,
}Expand description
Delta-only shortlist upload request.
Fields
agent_ids_to_add: Vec<AgentId>Trait Implementations
Sourceimpl Clone for CreateChallengeShortlistRevisionRequest
impl Clone for CreateChallengeShortlistRevisionRequest
Sourcefn clone(&self) -> CreateChallengeShortlistRevisionRequest
fn clone(&self) -> CreateChallengeShortlistRevisionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CreateChallengeShortlistRevisionRequest
impl<'de> Deserialize<'de> for CreateChallengeShortlistRevisionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateChallengeShortlistRevisionRequest
impl JsonSchema for CreateChallengeShortlistRevisionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Validate for CreateChallengeShortlistRevisionRequest
impl Validate for CreateChallengeShortlistRevisionRequest
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for CreateChallengeShortlistRevisionRequest
impl RefUnwindSafe for CreateChallengeShortlistRevisionRequest
impl Send for CreateChallengeShortlistRevisionRequest
impl Sync for CreateChallengeShortlistRevisionRequest
impl Unpin for CreateChallengeShortlistRevisionRequest
impl UnsafeUnpin for CreateChallengeShortlistRevisionRequest
impl UnwindSafe for CreateChallengeShortlistRevisionRequest