pub struct CreatePioneerCodeRequest {
pub label: Option<String>,
pub note: Option<String>,
pub max_uses: i64,
pub expires_at: Option<String>,
}Expand description
Admin payload for creating a pioneer code.
Fields
label: Option<String>note: Option<String>max_uses: i64expires_at: Option<String>Trait Implementations
Sourceimpl Clone for CreatePioneerCodeRequest
impl Clone for CreatePioneerCodeRequest
Sourcefn clone(&self) -> CreatePioneerCodeRequest
fn clone(&self) -> CreatePioneerCodeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreatePioneerCodeRequest
impl Debug for CreatePioneerCodeRequest
Sourceimpl<'de> Deserialize<'de> for CreatePioneerCodeRequest
impl<'de> Deserialize<'de> for CreatePioneerCodeRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreatePioneerCodeRequest
impl JsonSchema for CreatePioneerCodeRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for CreatePioneerCodeRequest
impl Serialize for CreatePioneerCodeRequest
Sourceimpl Validate for CreatePioneerCodeRequest
impl Validate for CreatePioneerCodeRequest
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for CreatePioneerCodeRequest
impl RefUnwindSafe for CreatePioneerCodeRequest
impl Send for CreatePioneerCodeRequest
impl Sync for CreatePioneerCodeRequest
impl Unpin for CreatePioneerCodeRequest
impl UnsafeUnpin for CreatePioneerCodeRequest
impl UnwindSafe for CreatePioneerCodeRequest