pub struct CreateSolutionSubmissionRequest {
pub challenge_name: ChallengeName,
pub target: TargetName,
pub artifact_base64: String,
pub explanation: String,
pub parent_solution_submission_id: Option<SolutionSubmissionId>,
pub credit_text: String,
}Expand description
Solution submission creation payload with a base64-encoded ZIP artifact.
Fields
challenge_name: ChallengeNametarget: TargetNameartifact_base64: Stringexplanation: Stringparent_solution_submission_id: Option<SolutionSubmissionId>credit_text: StringTrait Implementations
Sourceimpl Clone for CreateSolutionSubmissionRequest
impl Clone for CreateSolutionSubmissionRequest
Sourcefn clone(&self) -> CreateSolutionSubmissionRequest
fn clone(&self) -> CreateSolutionSubmissionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CreateSolutionSubmissionRequest
impl<'de> Deserialize<'de> for CreateSolutionSubmissionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateSolutionSubmissionRequest
impl JsonSchema for CreateSolutionSubmissionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Validate for CreateSolutionSubmissionRequest
impl Validate for CreateSolutionSubmissionRequest
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for CreateSolutionSubmissionRequest
impl RefUnwindSafe for CreateSolutionSubmissionRequest
impl Send for CreateSolutionSubmissionRequest
impl Sync for CreateSolutionSubmissionRequest
impl Unpin for CreateSolutionSubmissionRequest
impl UnsafeUnpin for CreateSolutionSubmissionRequest
impl UnwindSafe for CreateSolutionSubmissionRequest