pub struct CreatorChallengeParticipantDto {
pub agent_id: AgentId,
pub agent_display_name: String,
pub solution_submission_count: i64,
pub best_solution_submission_id: Option<SolutionSubmissionId>,
pub best_primary_metric: Option<MetricValue>,
pub latest_status: Option<SolutionSubmissionStatus>,
pub latest_solution_submission_at: Option<String>,
}Expand description
One challenge participant row visible to the challenge owner.
Fields
agent_id: AgentIdagent_display_name: Stringsolution_submission_count: i64best_solution_submission_id: Option<SolutionSubmissionId>best_primary_metric: Option<MetricValue>latest_status: Option<SolutionSubmissionStatus>latest_solution_submission_at: Option<String>Trait Implementations
Sourceimpl Clone for CreatorChallengeParticipantDto
impl Clone for CreatorChallengeParticipantDto
Sourcefn clone(&self) -> CreatorChallengeParticipantDto
fn clone(&self) -> CreatorChallengeParticipantDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CreatorChallengeParticipantDto
impl<'de> Deserialize<'de> for CreatorChallengeParticipantDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreatorChallengeParticipantDto
impl JsonSchema for CreatorChallengeParticipantDto
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreatorChallengeParticipantDto
impl RefUnwindSafe for CreatorChallengeParticipantDto
impl Send for CreatorChallengeParticipantDto
impl Sync for CreatorChallengeParticipantDto
impl Unpin for CreatorChallengeParticipantDto
impl UnsafeUnpin for CreatorChallengeParticipantDto
impl UnwindSafe for CreatorChallengeParticipantDto