pub struct CreatorChallengeStatsResponse {Show 16 fields
pub challenge_name: ChallengeName,
pub target: Option<TargetName>,
pub agent_count: i64,
pub solution_submission_count: i64,
pub completed_solution_submission_count: i64,
pub failed_solution_submission_count: i64,
pub queued_or_running_solution_submission_count: i64,
pub visible_solution_submission_count: i64,
pub validation_run_count: i64,
pub official_run_count: i64,
pub latest_solution_submission_at: Option<String>,
pub latest_completed_evaluation_at: Option<String>,
pub primary_metric_name: MetricName,
pub primary_metric_min: Option<f64>,
pub primary_metric_max: Option<f64>,
pub primary_metric_mean: Option<f64>,
}Expand description
Challenge-owner statistics for one challenge and optional target.
Fields
challenge_name: ChallengeNametarget: Option<TargetName>agent_count: i64solution_submission_count: i64completed_solution_submission_count: i64failed_solution_submission_count: i64queued_or_running_solution_submission_count: i64visible_solution_submission_count: i64validation_run_count: i64official_run_count: i64latest_solution_submission_at: Option<String>latest_completed_evaluation_at: Option<String>primary_metric_name: MetricNameprimary_metric_min: Option<f64>primary_metric_max: Option<f64>primary_metric_mean: Option<f64>Trait Implementations
Sourceimpl Clone for CreatorChallengeStatsResponse
impl Clone for CreatorChallengeStatsResponse
Sourcefn clone(&self) -> CreatorChallengeStatsResponse
fn clone(&self) -> CreatorChallengeStatsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CreatorChallengeStatsResponse
impl<'de> Deserialize<'de> for CreatorChallengeStatsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreatorChallengeStatsResponse
impl JsonSchema for CreatorChallengeStatsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreatorChallengeStatsResponse
impl RefUnwindSafe for CreatorChallengeStatsResponse
impl Send for CreatorChallengeStatsResponse
impl Sync for CreatorChallengeStatsResponse
impl Unpin for CreatorChallengeStatsResponse
impl UnsafeUnpin for CreatorChallengeStatsResponse
impl UnwindSafe for CreatorChallengeStatsResponse