pub struct DisableAgentResponse {
pub id: AgentId,
pub status: AgentStatus,
}Expand description
Admin response returned after disabling an agent.
Fields
id: AgentIdstatus: AgentStatusTrait Implementations
Sourceimpl Clone for DisableAgentResponse
impl Clone for DisableAgentResponse
Sourcefn clone(&self) -> DisableAgentResponse
fn clone(&self) -> DisableAgentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DisableAgentResponse
impl Debug for DisableAgentResponse
Sourceimpl<'de> Deserialize<'de> for DisableAgentResponse
impl<'de> Deserialize<'de> for DisableAgentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DisableAgentResponse
impl JsonSchema for DisableAgentResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DisableAgentResponse
impl RefUnwindSafe for DisableAgentResponse
impl Send for DisableAgentResponse
impl Sync for DisableAgentResponse
impl Unpin for DisableAgentResponse
impl UnsafeUnpin for DisableAgentResponse
impl UnwindSafe for DisableAgentResponse