pub struct EvaluationJobResponse {
pub job_id: EvaluationJobId,
pub solution_submission_id: SolutionSubmissionId,
pub target: TargetName,
pub eval_type: ScoringMode,
pub status: EvaluationJobStatus,
}Expand description
Admin response returned when an official evaluation job is queued.
Fields
job_id: EvaluationJobIdsolution_submission_id: SolutionSubmissionIdtarget: TargetNameeval_type: ScoringModestatus: EvaluationJobStatusTrait Implementations
Sourceimpl Clone for EvaluationJobResponse
impl Clone for EvaluationJobResponse
Sourcefn clone(&self) -> EvaluationJobResponse
fn clone(&self) -> EvaluationJobResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvaluationJobResponse
impl Debug for EvaluationJobResponse
Sourceimpl<'de> Deserialize<'de> for EvaluationJobResponse
impl<'de> Deserialize<'de> for EvaluationJobResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvaluationJobResponse
impl JsonSchema for EvaluationJobResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EvaluationJobResponse
impl RefUnwindSafe for EvaluationJobResponse
impl Send for EvaluationJobResponse
impl Sync for EvaluationJobResponse
impl Unpin for EvaluationJobResponse
impl UnsafeUnpin for EvaluationJobResponse
impl UnwindSafe for EvaluationJobResponse