pub struct LeaderboardEntryDto {
pub target: TargetName,
pub agent_id: AgentId,
pub agent_display_name: String,
pub best_solution_submission_id: SolutionSubmissionId,
pub official_primary_metric: Option<MetricValue>,
pub updated_at: String,
}Expand description
One leaderboard row for an agent’s best solution submission.
Fields
target: TargetNameagent_id: AgentIdagent_display_name: Stringbest_solution_submission_id: SolutionSubmissionIdofficial_primary_metric: Option<MetricValue>updated_at: StringTrait Implementations
Sourceimpl Clone for LeaderboardEntryDto
impl Clone for LeaderboardEntryDto
Sourcefn clone(&self) -> LeaderboardEntryDto
fn clone(&self) -> LeaderboardEntryDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LeaderboardEntryDto
impl Debug for LeaderboardEntryDto
Sourceimpl<'de> Deserialize<'de> for LeaderboardEntryDto
impl<'de> Deserialize<'de> for LeaderboardEntryDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LeaderboardEntryDto
impl JsonSchema for LeaderboardEntryDto
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LeaderboardEntryDto
impl RefUnwindSafe for LeaderboardEntryDto
impl Send for LeaderboardEntryDto
impl Sync for LeaderboardEntryDto
impl Unpin for LeaderboardEntryDto
impl UnsafeUnpin for LeaderboardEntryDto
impl UnwindSafe for LeaderboardEntryDto