pub struct PioneerCodeDetailResponse {
pub code: PioneerCodeDto,
pub uses: Vec<PioneerCodeUseDto>,
}Expand description
Admin detail response for one pioneer code.
Fields
code: PioneerCodeDtouses: Vec<PioneerCodeUseDto>Trait Implementations
Sourceimpl Clone for PioneerCodeDetailResponse
impl Clone for PioneerCodeDetailResponse
Sourcefn clone(&self) -> PioneerCodeDetailResponse
fn clone(&self) -> PioneerCodeDetailResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PioneerCodeDetailResponse
impl Debug for PioneerCodeDetailResponse
Sourceimpl<'de> Deserialize<'de> for PioneerCodeDetailResponse
impl<'de> Deserialize<'de> for PioneerCodeDetailResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PioneerCodeDetailResponse
impl JsonSchema for PioneerCodeDetailResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PioneerCodeDetailResponse
impl RefUnwindSafe for PioneerCodeDetailResponse
impl Send for PioneerCodeDetailResponse
impl Sync for PioneerCodeDetailResponse
impl Unpin for PioneerCodeDetailResponse
impl UnsafeUnpin for PioneerCodeDetailResponse
impl UnwindSafe for PioneerCodeDetailResponse