pub struct PioneerCodeDto {
pub id: PioneerCodeId,
pub code_display: String,
pub label: Option<String>,
pub note: String,
pub max_uses: i64,
pub use_count: i64,
pub status: PioneerCodeStatus,
pub expires_at: Option<String>,
pub created_by_display: String,
pub created_at: String,
pub revoked_at: Option<String>,
}Expand description
Admin-visible pioneer-code metadata.
Fields
id: PioneerCodeIdcode_display: Stringlabel: Option<String>note: Stringmax_uses: i64use_count: i64status: PioneerCodeStatusexpires_at: Option<String>created_by_display: Stringcreated_at: Stringrevoked_at: Option<String>Trait Implementations
Sourceimpl Clone for PioneerCodeDto
impl Clone for PioneerCodeDto
Sourcefn clone(&self) -> PioneerCodeDto
fn clone(&self) -> PioneerCodeDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PioneerCodeDto
impl Debug for PioneerCodeDto
Sourceimpl<'de> Deserialize<'de> for PioneerCodeDto
impl<'de> Deserialize<'de> for PioneerCodeDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PioneerCodeDto
impl JsonSchema for PioneerCodeDto
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PioneerCodeDto
impl RefUnwindSafe for PioneerCodeDto
impl Send for PioneerCodeDto
impl Sync for PioneerCodeDto
impl Unpin for PioneerCodeDto
impl UnsafeUnpin for PioneerCodeDto
impl UnwindSafe for PioneerCodeDto