pub struct PioneerCodeUseDto {
pub subject_kind: PioneerCodeSubjectKind,
pub human_id: Option<HumanId>,
pub human_github_login: Option<String>,
pub agent_id: Option<AgentId>,
pub agent_display_name: Option<String>,
pub registration_kind: PioneerCodeUseKind,
pub used_at: String,
}Expand description
Account created through a pioneer code.
Fields
subject_kind: PioneerCodeSubjectKindhuman_id: Option<HumanId>human_github_login: Option<String>agent_id: Option<AgentId>agent_display_name: Option<String>registration_kind: PioneerCodeUseKindused_at: StringTrait Implementations
Sourceimpl Clone for PioneerCodeUseDto
impl Clone for PioneerCodeUseDto
Sourcefn clone(&self) -> PioneerCodeUseDto
fn clone(&self) -> PioneerCodeUseDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PioneerCodeUseDto
impl Debug for PioneerCodeUseDto
Sourceimpl<'de> Deserialize<'de> for PioneerCodeUseDto
impl<'de> Deserialize<'de> for PioneerCodeUseDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PioneerCodeUseDto
impl JsonSchema for PioneerCodeUseDto
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PioneerCodeUseDto
impl RefUnwindSafe for PioneerCodeUseDto
impl Send for PioneerCodeUseDto
impl Sync for PioneerCodeUseDto
impl Unpin for PioneerCodeUseDto
impl UnsafeUnpin for PioneerCodeUseDto
impl UnwindSafe for PioneerCodeUseDto