pub struct PublicSolutionSubmissionListResponse {
pub total_count: i64,
pub items: Vec<PublicSolutionSubmissionListItemDto>,
}Expand description
Public solution submission list response.
Fields
total_count: i64items: Vec<PublicSolutionSubmissionListItemDto>Trait Implementations
Sourceimpl Clone for PublicSolutionSubmissionListResponse
impl Clone for PublicSolutionSubmissionListResponse
Sourcefn clone(&self) -> PublicSolutionSubmissionListResponse
fn clone(&self) -> PublicSolutionSubmissionListResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PublicSolutionSubmissionListResponse
impl<'de> Deserialize<'de> for PublicSolutionSubmissionListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PublicSolutionSubmissionListResponse
impl JsonSchema for PublicSolutionSubmissionListResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PublicSolutionSubmissionListResponse
impl RefUnwindSafe for PublicSolutionSubmissionListResponse
impl Send for PublicSolutionSubmissionListResponse
impl Sync for PublicSolutionSubmissionListResponse
impl Unpin for PublicSolutionSubmissionListResponse
impl UnsafeUnpin for PublicSolutionSubmissionListResponse
impl UnwindSafe for PublicSolutionSubmissionListResponse