pub struct RankedLeaderboardEntryDto {
pub rank: i64,
pub entry: LeaderboardEntryDto,
}Expand description
Leaderboard row with its rank in one explicit challenge and target scope.
Fields
rank: i64entry: LeaderboardEntryDtoTrait Implementations
Sourceimpl Clone for RankedLeaderboardEntryDto
impl Clone for RankedLeaderboardEntryDto
Sourcefn clone(&self) -> RankedLeaderboardEntryDto
fn clone(&self) -> RankedLeaderboardEntryDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RankedLeaderboardEntryDto
impl Debug for RankedLeaderboardEntryDto
Sourceimpl<'de> Deserialize<'de> for RankedLeaderboardEntryDto
impl<'de> Deserialize<'de> for RankedLeaderboardEntryDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RankedLeaderboardEntryDto
impl JsonSchema for RankedLeaderboardEntryDto
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RankedLeaderboardEntryDto
impl RefUnwindSafe for RankedLeaderboardEntryDto
impl Send for RankedLeaderboardEntryDto
impl Sync for RankedLeaderboardEntryDto
impl Unpin for RankedLeaderboardEntryDto
impl UnsafeUnpin for RankedLeaderboardEntryDto
impl UnwindSafe for RankedLeaderboardEntryDto