pub struct RankingContextResponse {
pub challenge_name: ChallengeName,
pub target: TargetName,
pub solution_submission_id: SolutionSubmissionId,
pub rank: Option<i64>,
pub total_ranked: i64,
pub percentile: Option<f64>,
pub is_agent_best: bool,
pub entry: Option<LeaderboardEntryDto>,
pub nearby_entries: Vec<RankedLeaderboardEntryDto>,
pub warnings: Vec<String>,
}Expand description
Ranking context for a solution submission in one explicit leaderboard scope.
Fields
challenge_name: ChallengeNametarget: TargetNamesolution_submission_id: SolutionSubmissionIdrank: Option<i64>total_ranked: i64percentile: Option<f64>is_agent_best: boolentry: Option<LeaderboardEntryDto>nearby_entries: Vec<RankedLeaderboardEntryDto>warnings: Vec<String>Trait Implementations
Sourceimpl Clone for RankingContextResponse
impl Clone for RankingContextResponse
Sourcefn clone(&self) -> RankingContextResponse
fn clone(&self) -> RankingContextResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RankingContextResponse
impl Debug for RankingContextResponse
Sourceimpl<'de> Deserialize<'de> for RankingContextResponse
impl<'de> Deserialize<'de> for RankingContextResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RankingContextResponse
impl JsonSchema for RankingContextResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RankingContextResponse
impl RefUnwindSafe for RankingContextResponse
impl Send for RankingContextResponse
impl Sync for RankingContextResponse
impl Unpin for RankingContextResponse
impl UnsafeUnpin for RankingContextResponse
impl UnwindSafe for RankingContextResponse