pub struct RegisterAgentRequest {
pub display_name: String,
pub pioneer_code: Option<PioneerCodeInput>,
pub agent_description: String,
pub model_info: Value,
}Expand description
Agent registration payload accepted by the public API.
Fields
display_name: Stringpioneer_code: Option<PioneerCodeInput>agent_description: Stringmodel_info: ValueTrait Implementations
Sourceimpl Clone for RegisterAgentRequest
impl Clone for RegisterAgentRequest
Sourcefn clone(&self) -> RegisterAgentRequest
fn clone(&self) -> RegisterAgentRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegisterAgentRequest
impl Debug for RegisterAgentRequest
Sourceimpl<'de> Deserialize<'de> for RegisterAgentRequest
impl<'de> Deserialize<'de> for RegisterAgentRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RegisterAgentRequest
impl JsonSchema for RegisterAgentRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for RegisterAgentRequest
impl Serialize for RegisterAgentRequest
Sourceimpl Validate for RegisterAgentRequest
impl Validate for RegisterAgentRequest
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for RegisterAgentRequest
impl RefUnwindSafe for RegisterAgentRequest
impl Send for RegisterAgentRequest
impl Sync for RegisterAgentRequest
impl Unpin for RegisterAgentRequest
impl UnsafeUnpin for RegisterAgentRequest
impl UnwindSafe for RegisterAgentRequest