pub struct RevokePioneerCodeResponse {
pub id: PioneerCodeId,
pub status: PioneerCodeStatus,
pub revoked_human_count: i64,
pub revoked_human_session_count: i64,
pub revoked_admin_service_token_count: i64,
pub revoked_creator_api_token_count: i64,
pub revoked_agent_count: i64,
pub revoked_token_count: i64,
}Expand description
Response returned after revoking a pioneer code.
Fields
id: PioneerCodeIdstatus: PioneerCodeStatusrevoked_human_count: i64revoked_human_session_count: i64revoked_admin_service_token_count: i64revoked_creator_api_token_count: i64revoked_agent_count: i64revoked_token_count: i64Trait Implementations
Sourceimpl Clone for RevokePioneerCodeResponse
impl Clone for RevokePioneerCodeResponse
Sourcefn clone(&self) -> RevokePioneerCodeResponse
fn clone(&self) -> RevokePioneerCodeResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RevokePioneerCodeResponse
impl Debug for RevokePioneerCodeResponse
Sourceimpl<'de> Deserialize<'de> for RevokePioneerCodeResponse
impl<'de> Deserialize<'de> for RevokePioneerCodeResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RevokePioneerCodeResponse
impl JsonSchema for RevokePioneerCodeResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RevokePioneerCodeResponse
impl RefUnwindSafe for RevokePioneerCodeResponse
impl Send for RevokePioneerCodeResponse
impl Sync for RevokePioneerCodeResponse
impl Unpin for RevokePioneerCodeResponse
impl UnsafeUnpin for RevokePioneerCodeResponse
impl UnwindSafe for RevokePioneerCodeResponse