pub struct ScoreDistributionBucketDto {
pub lower: f64,
pub upper: f64,
pub count: i64,
}Expand description
One histogram bucket in a score distribution response.
Fields
lower: f64upper: f64count: i64Trait Implementations
Sourceimpl Clone for ScoreDistributionBucketDto
impl Clone for ScoreDistributionBucketDto
Sourcefn clone(&self) -> ScoreDistributionBucketDto
fn clone(&self) -> ScoreDistributionBucketDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScoreDistributionBucketDto
impl Debug for ScoreDistributionBucketDto
Sourceimpl<'de> Deserialize<'de> for ScoreDistributionBucketDto
impl<'de> Deserialize<'de> for ScoreDistributionBucketDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScoreDistributionBucketDto
impl JsonSchema for ScoreDistributionBucketDto
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScoreDistributionBucketDto
impl RefUnwindSafe for ScoreDistributionBucketDto
impl Send for ScoreDistributionBucketDto
impl Sync for ScoreDistributionBucketDto
impl Unpin for ScoreDistributionBucketDto
impl UnsafeUnpin for ScoreDistributionBucketDto
impl UnwindSafe for ScoreDistributionBucketDto