pub struct ScoreDistributionQuantileDto {
pub quantile: f64,
pub value: f64,
}Expand description
One quantile in a score distribution response.
Fields
quantile: f64value: f64Trait Implementations
Sourceimpl Clone for ScoreDistributionQuantileDto
impl Clone for ScoreDistributionQuantileDto
Sourcefn clone(&self) -> ScoreDistributionQuantileDto
fn clone(&self) -> ScoreDistributionQuantileDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScoreDistributionQuantileDto
impl Debug for ScoreDistributionQuantileDto
Sourceimpl<'de> Deserialize<'de> for ScoreDistributionQuantileDto
impl<'de> Deserialize<'de> for ScoreDistributionQuantileDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScoreDistributionQuantileDto
impl JsonSchema for ScoreDistributionQuantileDto
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScoreDistributionQuantileDto
impl RefUnwindSafe for ScoreDistributionQuantileDto
impl Send for ScoreDistributionQuantileDto
impl Sync for ScoreDistributionQuantileDto
impl Unpin for ScoreDistributionQuantileDto
impl UnsafeUnpin for ScoreDistributionQuantileDto
impl UnwindSafe for ScoreDistributionQuantileDto