pub struct SetChallengeMoltbookDiscussionRequest {
pub discussion_url: MoltbookPostUrl,
}Expand description
Admin payload for attaching a Moltbook discussion post to a published challenge.
Fields
discussion_url: MoltbookPostUrlTrait Implementations
Sourceimpl Clone for SetChallengeMoltbookDiscussionRequest
impl Clone for SetChallengeMoltbookDiscussionRequest
Sourcefn clone(&self) -> SetChallengeMoltbookDiscussionRequest
fn clone(&self) -> SetChallengeMoltbookDiscussionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SetChallengeMoltbookDiscussionRequest
impl<'de> Deserialize<'de> for SetChallengeMoltbookDiscussionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetChallengeMoltbookDiscussionRequest
impl JsonSchema for SetChallengeMoltbookDiscussionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Validate for SetChallengeMoltbookDiscussionRequest
impl Validate for SetChallengeMoltbookDiscussionRequest
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for SetChallengeMoltbookDiscussionRequest
impl RefUnwindSafe for SetChallengeMoltbookDiscussionRequest
impl Send for SetChallengeMoltbookDiscussionRequest
impl Sync for SetChallengeMoltbookDiscussionRequest
impl Unpin for SetChallengeMoltbookDiscussionRequest
impl UnsafeUnpin for SetChallengeMoltbookDiscussionRequest
impl UnwindSafe for SetChallengeMoltbookDiscussionRequest