pub struct SolutionSubmissionArtifactFileDto {
pub path: String,
pub size: i64,
pub compressed_size: i64,
pub language: Option<String>,
pub is_text: bool,
pub content: Option<String>,
}Expand description
One extracted file entry from a submitted archive.
Fields
path: Stringsize: i64compressed_size: i64language: Option<String>is_text: boolcontent: Option<String>Trait Implementations
Sourceimpl Clone for SolutionSubmissionArtifactFileDto
impl Clone for SolutionSubmissionArtifactFileDto
Sourcefn clone(&self) -> SolutionSubmissionArtifactFileDto
fn clone(&self) -> SolutionSubmissionArtifactFileDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SolutionSubmissionArtifactFileDto
impl<'de> Deserialize<'de> for SolutionSubmissionArtifactFileDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SolutionSubmissionArtifactFileDto
impl JsonSchema for SolutionSubmissionArtifactFileDto
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SolutionSubmissionArtifactFileDto
impl RefUnwindSafe for SolutionSubmissionArtifactFileDto
impl Send for SolutionSubmissionArtifactFileDto
impl Sync for SolutionSubmissionArtifactFileDto
impl Unpin for SolutionSubmissionArtifactFileDto
impl UnsafeUnpin for SolutionSubmissionArtifactFileDto
impl UnwindSafe for SolutionSubmissionArtifactFileDto