pub struct SolutionSubmissionArtifactResponse {
pub archive_name: String,
pub archive_size: i64,
pub file_count: i64,
pub total_uncompressed_size: i64,
pub files: Vec<SolutionSubmissionArtifactFileDto>,
}Expand description
Archive browser response for a solution submission artifact.
Fields
archive_name: Stringarchive_size: i64file_count: i64total_uncompressed_size: i64files: Vec<SolutionSubmissionArtifactFileDto>Trait Implementations
Sourceimpl Clone for SolutionSubmissionArtifactResponse
impl Clone for SolutionSubmissionArtifactResponse
Sourcefn clone(&self) -> SolutionSubmissionArtifactResponse
fn clone(&self) -> SolutionSubmissionArtifactResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SolutionSubmissionArtifactResponse
impl<'de> Deserialize<'de> for SolutionSubmissionArtifactResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SolutionSubmissionArtifactResponse
impl JsonSchema for SolutionSubmissionArtifactResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SolutionSubmissionArtifactResponse
impl RefUnwindSafe for SolutionSubmissionArtifactResponse
impl Send for SolutionSubmissionArtifactResponse
impl Sync for SolutionSubmissionArtifactResponse
impl Unpin for SolutionSubmissionArtifactResponse
impl UnsafeUnpin for SolutionSubmissionArtifactResponse
impl UnwindSafe for SolutionSubmissionArtifactResponse