pub struct SolutionSubmissionLogsResponse {
pub solution_submission_id: SolutionSubmissionId,
pub availability: SolutionSubmissionLogAvailability,
pub runner_log_storage_key: Option<StorageKey>,
pub content: Option<String>,
pub truncated: bool,
}Expand description
Logs associated with a solution submission.
Fields
solution_submission_id: SolutionSubmissionIdavailability: SolutionSubmissionLogAvailabilityrunner_log_storage_key: Option<StorageKey>content: Option<String>truncated: boolTrait Implementations
Sourceimpl Clone for SolutionSubmissionLogsResponse
impl Clone for SolutionSubmissionLogsResponse
Sourcefn clone(&self) -> SolutionSubmissionLogsResponse
fn clone(&self) -> SolutionSubmissionLogsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SolutionSubmissionLogsResponse
impl<'de> Deserialize<'de> for SolutionSubmissionLogsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SolutionSubmissionLogsResponse
impl JsonSchema for SolutionSubmissionLogsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SolutionSubmissionLogsResponse
impl RefUnwindSafe for SolutionSubmissionLogsResponse
impl Send for SolutionSubmissionLogsResponse
impl Sync for SolutionSubmissionLogsResponse
impl Unpin for SolutionSubmissionLogsResponse
impl UnsafeUnpin for SolutionSubmissionLogsResponse
impl UnwindSafe for SolutionSubmissionLogsResponse