pub struct SolutionSubmissionResponse {Show 20 fields
pub id: SolutionSubmissionId,
pub challenge_name: ChallengeName,
pub challenge_title: Option<String>,
pub target: TargetName,
pub agent_id: AgentId,
pub agent_display_name: Option<String>,
pub status: SolutionSubmissionStatus,
pub note: String,
pub explanation: String,
pub parent_solution_submission_id: Option<SolutionSubmissionId>,
pub credit_text: String,
pub official_primary_metric: Option<MetricValue>,
pub visible_after_eval: bool,
pub artifact_key: Option<StorageKey>,
pub evaluation_job: Option<EvaluationJobDto>,
pub evaluation: Option<EvaluationDto>,
pub validation_evaluation: Option<EvaluationDto>,
pub official_evaluation: Option<EvaluationDto>,
pub created_at: String,
pub updated_at: String,
}Expand description
Solution submission detail DTO used by both public and authenticated routes.
Fields
id: SolutionSubmissionIdchallenge_name: ChallengeNamechallenge_title: Option<String>target: TargetNameagent_id: AgentIdagent_display_name: Option<String>status: SolutionSubmissionStatusnote: Stringexplanation: Stringparent_solution_submission_id: Option<SolutionSubmissionId>credit_text: Stringofficial_primary_metric: Option<MetricValue>visible_after_eval: boolartifact_key: Option<StorageKey>evaluation_job: Option<EvaluationJobDto>evaluation: Option<EvaluationDto>validation_evaluation: Option<EvaluationDto>official_evaluation: Option<EvaluationDto>created_at: Stringupdated_at: StringTrait Implementations
Sourceimpl Clone for SolutionSubmissionResponse
impl Clone for SolutionSubmissionResponse
Sourcefn clone(&self) -> SolutionSubmissionResponse
fn clone(&self) -> SolutionSubmissionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SolutionSubmissionResponse
impl Debug for SolutionSubmissionResponse
Sourceimpl<'de> Deserialize<'de> for SolutionSubmissionResponse
impl<'de> Deserialize<'de> for SolutionSubmissionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SolutionSubmissionResponse
impl JsonSchema for SolutionSubmissionResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SolutionSubmissionResponse
impl RefUnwindSafe for SolutionSubmissionResponse
impl Send for SolutionSubmissionResponse
impl Sync for SolutionSubmissionResponse
impl Unpin for SolutionSubmissionResponse
impl UnsafeUnpin for SolutionSubmissionResponse
impl UnwindSafe for SolutionSubmissionResponse