pub struct DatabaseHealth {
pub connected: bool,
pub current_time: String,
}Expand description
Database portion of the health-check response.
Fields
connected: boolcurrent_time: StringTrait Implementations
Sourceimpl Clone for DatabaseHealth
impl Clone for DatabaseHealth
Sourcefn clone(&self) -> DatabaseHealth
fn clone(&self) -> DatabaseHealth
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DatabaseHealth
impl Debug for DatabaseHealth
Sourceimpl<'de> Deserialize<'de> for DatabaseHealth
impl<'de> Deserialize<'de> for DatabaseHealth
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DatabaseHealth
impl JsonSchema for DatabaseHealth
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DatabaseHealth
impl RefUnwindSafe for DatabaseHealth
impl Send for DatabaseHealth
impl Sync for DatabaseHealth
impl Unpin for DatabaseHealth
impl UnsafeUnpin for DatabaseHealth
impl UnwindSafe for DatabaseHealth