pub struct IdOnlyResponse {
pub id: String,
}Expand description
Generic response for endpoints that only need to return an id.
Fields
id: StringTrait Implementations
Sourceimpl Clone for IdOnlyResponse
impl Clone for IdOnlyResponse
Sourcefn clone(&self) -> IdOnlyResponse
fn clone(&self) -> IdOnlyResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdOnlyResponse
impl Debug for IdOnlyResponse
Sourceimpl<'de> Deserialize<'de> for IdOnlyResponse
impl<'de> Deserialize<'de> for IdOnlyResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IdOnlyResponse
impl JsonSchema for IdOnlyResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for IdOnlyResponse
impl RefUnwindSafe for IdOnlyResponse
impl Send for IdOnlyResponse
impl Sync for IdOnlyResponse
impl Unpin for IdOnlyResponse
impl UnsafeUnpin for IdOnlyResponse
impl UnwindSafe for IdOnlyResponse